| Title: | Templates for 'ggplot2' and 'R Markdown' |
|---|---|
| Description: | Templates for 'ggplot2' and 'R Markdown'. 'opensky' provides functions to include templates for 'xaringan' slides, 'ggplot2' helpers, and 'R Markdown' documents. |
| Authors: | Malcolm Barrett [aut, cre] (ORCID: <https://orcid.org/0000-0003-0299-5825>) |
| Maintainer: | Malcolm Barrett <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.0 |
| Built: | 2026-05-14 06:15:02 UTC |
| Source: | https://github.com/emptyfield-ds/opensky |
Use a blank R Markdown file with reasonable settings
use_blank_rmd(save_as, open = is_interactive())use_blank_rmd(save_as, open = is_interactive())
save_as |
Path of file to create, relative to root of active project.
Defaults to |
open |
Open the newly created file for editing? Happens in RStudio, if
applicable, or via |
Including theme_minimal2(), geom_point2(), and other variants
use_ggplot2_utils(save_as = NULL, open = FALSE)use_ggplot2_utils(save_as = NULL, open = FALSE)
save_as |
Path of file to create, relative to root of active project.
Defaults to |
open |
Open the newly created file for editing? Happens in RStudio, if
applicable, or via |
compat-purrr.R from rlangUse compat-purrr.R from rlang
use_purrr_compat(save_as = "compat-purrr.R", open = is_interactive())use_purrr_compat(save_as = "compat-purrr.R", open = is_interactive())
save_as |
Path of file to create, relative to root of active project.
Defaults to |
open |
Open the newly created file for editing? Happens in RStudio, if
applicable, or via |
rhub.R fileUse an ignored rhub.R file
use_r_hub(save_as = "rhub.R", open = is_interactive())use_r_hub(save_as = "rhub.R", open = is_interactive())
save_as |
Path of file to create, relative to root of active project.
Defaults to |
open |
Open the newly created file for editing? Happens in RStudio, if
applicable, or via |
setup.R in the testthat fileCreate setup.R in the testthat file
use_testthat_setup(open = is_interactive())use_testthat_setup(open = is_interactive())
open |
Open the newly created file for editing? Happens in RStudio, if
applicable, or via |
utils.R with %||% and %nin%
Use utils.R with %||% and %nin%
use_utils(save_as = "utils.R", open = is_interactive()) edit_utils(open = is_interactive())use_utils(save_as = "utils.R", open = is_interactive()) edit_utils(open = is_interactive())
save_as |
Path of file to create, relative to root of active project.
Defaults to |
open |
Open the newly created file for editing? Happens in RStudio, if
applicable, or via |
Use xaringan templates
use_xaringan_kakashi(save_as, open = is_interactive()) use_xaringan_tozan(save_as, open = is_interactive())use_xaringan_kakashi(save_as, open = is_interactive()) use_xaringan_tozan(save_as, open = is_interactive())
save_as |
Path of file to create, relative to root of active project.
Defaults to |
open |
Open the newly created file for editing? Happens in RStudio, if
applicable, or via |